<h1 align="center">
  <b>PyhDToolkit</b>
</h1>

<p align="center">
  <!-- PyPi Version -->
  <a href="https://pypi.org/project/cpymadtools">
    <img alt="PyPI Version" src="https://img.shields.io/pypi/v/cpymadtools?label=PyPI&logo=PyPI">
  </a>

  <!-- Github Release -->
  <a href="https://github.com/fsoubelet/cpymadtools/releases">
    <img alt="Github Release" src="https://img.shields.io/github/v/release/fsoubelet/cpymadtools?color=orange&label=Release&logo=Github">
  </a>

  <br/>

  <!-- Github Actions Build -->
  <a href="https://github.com/fsoubelet/cpymadtools/actions?query=workflow%3A%22Cron+Testing%22">
    <img alt="Github Actions" src="https://github.com/fsoubelet/cpymadtools/workflows/Tests/badge.svg">
  </a>

  <!-- Code Coverage -->
  <a href="https://codecov.io/gh/fsoubelet/cpymadtools">
    <img src="https://codecov.io/gh/fsoubelet/cpymadtools/branch/master/graph/badge.svg?token=6SO90F2MJI"/>
  </a>

  <br/>

  <!-- Code style -->
  <a href="https://github.com/psf/Black">
    <img alt="Code Style" src="https://img.shields.io/badge/Code%20Style-Black-9cf.svg">
  </a>

  <!-- Linter -->
  <a href="https://github.com/PyCQA/pylint">
    <img alt="Linter" src="https://img.shields.io/badge/Linter-Pylint-ce963f.svg">
  </a>

  <!-- Build tool -->
  <a href="https://github.com/pypa/hatch">
    <img alt="Build tool" src="https://img.shields.io/badge/Build%20Tool-Hatch-4e5dc8.svg">
  </a>

  <!-- Test runner -->
  <a href="https://github.com/pytest-dev/pytest">
    <img alt="Test runner" src="https://img.shields.io/badge/Test%20Runner-Pytest-ce963f.svg">
  </a>

  <!-- License -->
  <a href="https://github.com/fsoubelet/cpymadtools/blob/master/LICENSE">
    <img alt="License" src="https://img.shields.io/github/license/fsoubelet/cpymadtools?color=9cf&label=License">
  </a>
</p>

<p align="center">
  Lightweigth pythonic wrapper around cpymad
</p>

<p align="center">
  <!-- General DOI -->
  <a href="https://zenodo.org/badge/latestdoi/227081702">
    <img alt="DOI" src="https://zenodo.org/badge/227081702.svg">
  </a>
</p>

Link to [documentation].

## License

Copyright &copy; 2019 Felix Soubelet. [MIT License](LICENSE)

[documentation]: https://fsoubelet.github.io/cpymadtools/
